@@ -9,8 +9,11 @@ from .abc import (
     AbstractDockerImageProgress,
     AbstractFileProgress,
     AbstractRecursiveFileProgress,
+    ImageCommitFinished,
+    ImageCommitStarted,
     ImageProgressPull,
     ImageProgressPush,
+    ImageProgressSave,
     ImageProgressStep,
     StorageProgressComplete,
     StorageProgressDelete,
@@ -115,6 +118,9 @@ __all__ = (
     "ImageProgressPull",
     "ImageProgressPush",
     "ImageProgressStep",
+    "ImageProgressSave",
+    "ImageCommitStarted",
+    "ImageCommitFinished",
     "TagOption",
     "RemoteImage",
     "LocalImage",
