@@ -115,6 +115,7 @@ class JobStatusHistory:
     status: JobStatus
     reason: str
     description: str
+    restarts: int
     created_at: Optional[datetime] = None
     started_at: Optional[datetime] = None
     finished_at: Optional[datetime] = None
@@ -147,7 +148,6 @@ class JobDescription:
     tags: Sequence[str] = ()
     description: Optional[str] = None
     http_url: URL = URL()
-    ssh_server: URL = URL()
     internal_hostname: Optional[str] = None
     internal_hostname_named: Optional[str] = None
     restart_policy: JobRestartPolicy = JobRestartPolicy.NEVER
@@ -744,6 +744,7 @@ def _job_description_from_api(res: Dict[str, Any], parse: Parser) -> JobDescript
         # Forward-compatible support for CANCELLED status
         status=_calc_status(res["history"].get("status", "unknown")),
         reason=res["history"].get("reason", ""),
+        restarts=res["history"].get("restarts", 0),
         description=res["history"].get("description", ""),
         created_at=_parse_datetime(res["history"].get("created_at")),
         started_at=_parse_datetime(res["history"].get("started_at")),
@@ -752,7 +753,6 @@ def _job_description_from_api(res: Dict[str, Any], parse: Parser) -> JobDescript
     )
     http_url = URL(res.get("http_url", ""))
     http_url_named = URL(res.get("http_url_named", ""))
-    ssh_server = URL(res.get("ssh_server", ""))
     internal_hostname = res.get("internal_hostname", None)
     internal_hostname_named = res.get("internal_hostname_named", None)
     restart_policy = JobRestartPolicy(res.get("restart_policy", JobRestartPolicy.NEVER))
@@ -772,7 +772,6 @@ def _job_description_from_api(res: Dict[str, Any], parse: Parser) -> JobDescript
         tags=tags,
         description=description,
         http_url=http_url_named or http_url,
-        ssh_server=ssh_server,
         internal_hostname=internal_hostname,
         internal_hostname_named=internal_hostname_named,
         uri=URL(res["uri"]),
