@@ -2,7 +2,6 @@ import asyncio
 import io
 import logging
 import os
-import shutil
 import sys
 import warnings
 from pathlib import Path
@@ -174,7 +173,6 @@ class MainGroup(Group):
             verbosity=verbosity,
             color=real_color,
             tty=tty,
-            terminal_size=shutil.get_terminal_size(),
             disable_pypi_version_check=kwargs["disable_pypi_version_check"],
             network_timeout=kwargs["network_timeout"],
             config_path=Path(kwargs["neuromation_config"]),
@@ -516,6 +514,13 @@ cli.add_command(alias(share.grant, "share", help=share.grant.help, deprecated=Fa
 cli.topics = topics
 
 
+def _err_to_str(err: Exception) -> str:
+    result = str(err)
+    if result == "":
+        result = type(err).__name__
+    return result
+
+
 def main(args: Optional[List[str]] = None) -> None:
     try:
         with warnings.catch_warnings():
@@ -535,34 +540,34 @@ def main(args: Optional[List[str]] = None) -> None:
         sys.exit(EX_TIMEOUT)
 
     except neuromation.api.errors.IllegalArgumentError as error:
-        LOG_ERROR(f"Illegal argument(s) ({error})")
+        LOG_ERROR(f"Illegal argument(s) ({_err_to_str(error)})")
         sys.exit(EX_DATAERR)
 
     except neuromation.api.errors.ResourceNotFound as error:
-        LOG_ERROR(f"{error}")
+        LOG_ERROR(f"{_err_to_str(error)}")
         sys.exit(EX_OSFILE)
 
     except neuromation.api.errors.AuthenticationError as error:
-        LOG_ERROR(f"Cannot authenticate ({error})")
+        LOG_ERROR(f"Cannot authenticate ({_err_to_str(error)})")
         sys.exit(EX_NOPERM)
     except neuromation.api.errors.AuthorizationError as error:
-        LOG_ERROR(f"Not enough permissions ({error})")
+        LOG_ERROR(f"Not enough permissions ({_err_to_str(error)})")
         sys.exit(EX_NOPERM)
 
     except neuromation.api.errors.ClientError as error:
-        LOG_ERROR(f"Application error ({error})")
+        LOG_ERROR(f"Application error ({_err_to_str(error)})")
         sys.exit(EX_SOFTWARE)
 
     except neuromation.api.errors.ServerNotAvailable as error:
-        LOG_ERROR(f"Application error ({error})")
+        LOG_ERROR(f"Application error ({_err_to_str(error)})")
         sys.exit(EX_PLATFORMERROR)
 
     except ConfigError as error:
-        LOG_ERROR(f"{error}")
+        LOG_ERROR(f"{_err_to_str(error)}")
         sys.exit(EX_SOFTWARE)
 
     except aiohttp.ClientError as error:
-        LOG_ERROR(f"Connection error ({error})")
+        LOG_ERROR(f"Connection error ({_err_to_str(error)})")
         sys.exit(EX_IOERR)
 
     except DockerError as error:
@@ -570,23 +575,23 @@ def main(args: Optional[List[str]] = None) -> None:
         sys.exit(EX_PROTOCOL)
 
     except NotImplementedError as error:
-        LOG_ERROR(f"{error}")
+        LOG_ERROR(f"{_err_to_str(error)}")
         sys.exit(EX_SOFTWARE)
 
     except FileNotFoundError as error:
-        LOG_ERROR(f"File not found ({error})")
+        LOG_ERROR(f"File not found ({_err_to_str(error)})")
         sys.exit(EX_OSFILE)
 
     except NotADirectoryError as error:
-        LOG_ERROR(f"{error}")
+        LOG_ERROR(f"{_err_to_str(error)}")
         sys.exit(EX_OSFILE)
 
     except PermissionError as error:
-        LOG_ERROR(f"Cannot access file ({error})")
+        LOG_ERROR(f"Cannot access file ({_err_to_str(error)})")
         sys.exit(EX_NOPERM)
 
     except OSError as error:
-        LOG_ERROR(f"I/O Error ({error})")
+        LOG_ERROR(f"I/O Error ({_err_to_str(error)})")
         sys.exit(EX_IOERR)
 
     except asyncio.CancelledError:
@@ -598,12 +603,12 @@ def main(args: Optional[List[str]] = None) -> None:
         sys.exit(130)
 
     except ValueError as e:
-        LOG_ERROR(e)
+        LOG_ERROR(_err_to_str(e))
         sys.exit(127)
 
     except SystemExit:
         raise
 
     except Exception as e:
-        LOG_ERROR(f"{e}")
+        LOG_ERROR(f"{_err_to_str(e)}")
         sys.exit(1)
