@@ -6,6 +6,7 @@ import asynctest
 import pytest
 from aiodocker.exceptions import DockerError
 from aiohttp import web
+from aiohttp.hdrs import LINK
 from yarl import URL
 
 from neuromation.api import (
@@ -229,10 +230,11 @@ class TestImageParser:
             "image:///ubuntu?key=value",
             "image:ubuntu?key=value",
             "image:5000?key=value",
+            "image://test-cluster/bob/ubuntu:v10.04?",
         ],
     )
     def test_parse_as_neuro_image__with_query__fail(self, url: str) -> None:
-        with pytest.raises(ValueError, match="query is not allowed"):
+        with pytest.raises(ValueError, match="Query part is not allowed in image URI"):
             self.parser.parse_as_neuro_image(url)
 
     @pytest.mark.parametrize(
@@ -243,25 +245,33 @@ class TestImageParser:
             "image:///ubuntu#fragment",
             "image:ubuntu#fragment",
             "image:5000#fragment",
+            "image://test-cluster/bob/ubuntu:v10.04#",
         ],
     )
     def test_parse_as_neuro_image__with_fragment__fail(self, url: str) -> None:
-        with pytest.raises(ValueError, match="fragment is not allowed"):
+        with pytest.raises(
+            ValueError, match="Fragment part is not allowed in image URI"
+        ):
             self.parser.parse_as_neuro_image(url)
 
     def test_parse_as_neuro_image__with_user__fail(self) -> None:
         url = "image://user@test-cluster/bob/ubuntu"
-        with pytest.raises(ValueError, match="user is not allowed"):
+        with pytest.raises(ValueError, match="User is not allowed in image URI"):
             self.parser.parse_as_neuro_image(url)
 
     def test_parse_as_neuro_image__with_password__fail(self) -> None:
         url = "image://:password@test-cluster/bob/ubuntu"
-        with pytest.raises(ValueError, match="password is not allowed"):
+        with pytest.raises(ValueError, match="Password is not allowed in image URI"):
+            self.parser.parse_as_neuro_image(url)
+
+    def test_parse_as_neuro_image__with_empty_password__fail(self) -> None:
+        url = "image://:@test-cluster/bob/ubuntu"
+        with pytest.raises(ValueError, match="Password is not allowed in image URI"):
             self.parser.parse_as_neuro_image(url)
 
     def test_parse_as_neuro_image__with_port__fail(self) -> None:
         url = "image://test-cluster:443/bob/ubuntu"
-        with pytest.raises(ValueError, match="port is not allowed"):
+        with pytest.raises(ValueError, match="Port is not allowed in image URI"):
             self.parser.parse_as_neuro_image(url)
 
     def test_parse_as_neuro_image_empty__fail(self) -> None:
@@ -577,6 +587,17 @@ class TestImageParser:
             registry="reg.neu.ro",
         )
 
+    def test_parse_as_neuro_image_with_scheme_special_chars(self) -> None:
+        image = "image://other-cluster/bob/ubuntu%23%25%3F%C3%9F:v10.04%23%25%3F%C3%9F"
+        parsed = self.parser.parse_as_neuro_image(image)
+        assert parsed == RemoteImage.new_neuro_image(
+            name="ubuntu#%?ß",
+            tag="v10.04#%?ß",
+            owner="bob",
+            cluster_name="other-cluster",
+            registry="reg.neu.ro",
+        )
+
     def test_parse_as_neuro_image_no_scheme_no_slash_no_tag_fail(self) -> None:
         image = "ubuntu"
         with pytest.raises(ValueError, match="scheme 'image:' is required"):
@@ -616,6 +637,18 @@ class TestImageParser:
         image = self.parser.parse_as_neuro_image("reg.neu.ro/user/image:tag")
         assert str(image) == "image://test-cluster/user/image:tag"
 
+    def test_parse_as_neuro_image_with_registry_prefix_special_chars(self) -> None:
+        image = self.parser.parse_as_neuro_image(
+            "reg.neu.ro/user/image%23%25%3F%C3%9F:tag%23%25%3F%C3%9F"
+        )
+        assert image == RemoteImage.new_neuro_image(
+            name="image#%?ß",
+            tag="tag#%?ß",
+            owner="user",
+            cluster_name="test-cluster",
+            registry="reg.neu.ro",
+        )
+
     def test_parse_as_neuro_image_no_scheme_3_slash_with_tag_fail(self) -> None:
         image = "something/docker.io/library/ubuntu:v10.04"
         with pytest.raises(ValueError, match="scheme 'image:' is required"):
@@ -1097,6 +1130,8 @@ class TestRegistry:
         JSON = {"repositories": ["bob/alpine", "jill/bananas"]}
 
         async def handler(request: web.Request) -> web.Response:
+            assert "n" in request.query
+            assert "last" not in request.query
             return web.json_response(JSON)
 
         app = web.Application()
@@ -1128,6 +1163,197 @@ class TestRegistry:
             ),
         }
 
+    async def test_ls_repositories_chunked(
+        self, aiohttp_server: _TestServerFactory, make_client: _MakeClient
+    ) -> None:
+        step = 0
+
+        async def handler(request: web.Request) -> web.Response:
+            nonlocal step
+            step += 1
+            headers: Dict[str, str]
+            assert "n" in request.query
+            if step == 1:
+                assert "last" not in request.query
+                payload = {"repositories": ["bob/alpine", "jill/bananas"]}
+                headers = {LINK: f'<{catalog_url}?last=lsttkn>; rel="next"'}
+                return web.json_response(payload, headers=headers)
+            elif step == 2:
+                assert request.query["last"] == "lsttkn"
+                payload = {"repositories": ["alice/library/ubuntu"]}
+                headers = {LINK: f'<{catalog_url}?last=lsttkn2>; rel="next"'}
+                return web.json_response(payload, headers=headers)
+            elif step == 3:
+                assert request.query["last"] == "lsttkn2"
+                payload = {"repositories": []}
+                headers = {LINK: f'<{catalog_url}?last=lsttkn3>; rel="next"'}
+                return web.json_response(payload, headers=headers)
+            else:  # pragma: no cover
+                assert False
+
+        app = web.Application()
+        app.router.add_get("/v2/_catalog", handler)
+
+        srv = await aiohttp_server(app)
+        url = "http://platform"
+        registry_url = srv.make_url("/v2/")
+        catalog_url = registry_url / "_catalog"
+
+        async with make_client(url, registry_url=registry_url) as client:
+            ret = await client.images.ls()
+        assert step == 3  # All steps are passed
+
+        registry = _get_url_authority(registry_url)
+        assert registry is not None
+        assert set(ret) == {
+            RemoteImage.new_neuro_image(
+                "alpine",
+                tag=None,
+                owner="bob",
+                cluster_name="default",
+                registry=registry,
+            ),
+            RemoteImage.new_neuro_image(
+                "library/ubuntu",
+                tag=None,
+                owner="alice",
+                cluster_name="default",
+                registry=registry,
+            ),
+            RemoteImage.new_neuro_image(
+                "bananas",
+                tag=None,
+                owner="jill",
+                cluster_name="default",
+                registry=registry,
+            ),
+        }
+
+    @pytest.mark.skipif(
+        sys.platform == "win32", reason="aiodocker doesn't support Windows pipes yet"
+    )
+    async def test_ls_tags(
+        self, aiohttp_server: _TestServerFactory, make_client: _MakeClient
+    ) -> None:
+        JSON = {"name": "test", "tags": ["alpha", "beta", "gamma"]}
+
+        async def handler(request: web.Request) -> web.Response:
+            assert "n" in request.query
+            assert "last" not in request.query
+            return web.json_response(JSON)
+
+        app = web.Application()
+        app.router.add_get("/v2/me/test/tags/list", handler)
+
+        srv = await aiohttp_server(app)
+        url = "http://platform"
+        registry_url = srv.make_url("/v2/")
+
+        async with make_client(url, registry_url=registry_url) as client:
+            image = RemoteImage.new_neuro_image(
+                name="test",
+                tag=None,
+                owner="me",
+                cluster_name="test-cluster",
+                registry="reg",
+            )
+            ret = await client.images.tags(image)
+
+        assert set(ret) == {
+            RemoteImage.new_neuro_image(
+                "test",
+                tag="alpha",
+                owner="me",
+                cluster_name="test-cluster",
+                registry="reg",
+            ),
+            RemoteImage.new_neuro_image(
+                "test",
+                tag="beta",
+                owner="me",
+                cluster_name="test-cluster",
+                registry="reg",
+            ),
+            RemoteImage.new_neuro_image(
+                "test",
+                tag="gamma",
+                owner="me",
+                cluster_name="test-cluster",
+                registry="reg",
+            ),
+        }
+
+    async def test_ls_tags_chunked(
+        self, aiohttp_server: _TestServerFactory, make_client: _MakeClient
+    ) -> None:
+        step = 0
+
+        async def handler(request: web.Request) -> web.Response:
+            nonlocal step
+            step += 1
+            headers: Dict[str, str]
+            assert "n" in request.query
+            if step == 1:
+                assert "last" not in request.query
+                payload = {"name": "test", "tags": ["alpha", "beta"]}
+                headers = {LINK: f'<{tags_list_url}?last=lsttkn>; rel="next"'}
+                return web.json_response(payload, headers=headers)
+            elif step == 2:
+                assert request.query["last"] == "lsttkn"
+                payload = {"name": "test", "tags": ["gamma"]}
+                headers = {LINK: f'<{tags_list_url}?last=lsttkn2>; rel="next"'}
+                return web.json_response(payload, headers=headers)
+            elif step == 3:
+                assert request.query["last"] == "lsttkn2"
+                payload = {"name": "test", "tags": []}
+                headers = {LINK: f'<{tags_list_url}?last=lsttkn3>; rel="next"'}
+                return web.json_response(payload, headers=headers)
+            else:  # pragma: no cover
+                assert False
+
+        app = web.Application()
+        app.router.add_get("/v2/me/test/tags/list", handler)
+
+        srv = await aiohttp_server(app)
+        url = "http://platform"
+        registry_url = srv.make_url("/v2/")
+        tags_list_url = registry_url / "me/test/tags/list"
+
+        async with make_client(url, registry_url=registry_url) as client:
+            image = RemoteImage.new_neuro_image(
+                name="test",
+                tag=None,
+                owner="me",
+                cluster_name="test-cluster",
+                registry="reg",
+            )
+            ret = await client.images.tags(image)
+        assert step == 3  # All steps are passed
+
+        assert set(ret) == {
+            RemoteImage.new_neuro_image(
+                "test",
+                tag="alpha",
+                owner="me",
+                cluster_name="test-cluster",
+                registry="reg",
+            ),
+            RemoteImage.new_neuro_image(
+                "test",
+                tag="beta",
+                owner="me",
+                cluster_name="test-cluster",
+                registry="reg",
+            ),
+            RemoteImage.new_neuro_image(
+                "test",
+                tag="gamma",
+                owner="me",
+                cluster_name="test-cluster",
+                registry="reg",
+            ),
+        }
+
     @pytest.mark.skipif(
         sys.platform == "win32", reason="aiodocker doesn't support Windows pipes yet"
     )
