@@ -463,8 +463,6 @@ async def test_status_failed(
         "id": "job-id",
         "description": "This is job description, not a history description",
         "http_url": "http://my_host:8889",
-        "ssh_server": "ssh://my_host.ssh:22",
-        "ssh_auth_server": "ssh://my_host.ssh:22",
         "history": {
             "created_at": "2018-08-29T12:23:13.981621+00:00",
             "started_at": "2018-08-29T12:23:15.988054+00:00",
@@ -516,7 +514,7 @@ async def test_status_failed(
         assert ret == _job_description_from_api(JSON, client.parse)
 
 
-async def test_status_with_ssh_and_http(
+async def test_status_with_http(
     aiohttp_server: _TestServerFactory, make_client: _MakeClient
 ) -> None:
     JSON = {
@@ -524,8 +522,6 @@ async def test_status_with_ssh_and_http(
         "id": "job-id",
         "description": "This is job description, not a history description",
         "http_url": "http://my_host:8889",
-        "ssh_server": "ssh://my_host.ssh:22",
-        "ssh_auth_server": "ssh://my_host.ssh:22",
         "history": {
             "created_at": "2018-08-29T12:23:13.981621+00:00",
             "started_at": "2018-08-29T12:23:15.988054+00:00",
@@ -585,8 +581,6 @@ async def test_status_with_tpu(
         "id": "job-id",
         "description": "This is job description, not a history description",
         "http_url": "http://my_host:8889",
-        "ssh_server": "ssh://my_host.ssh:22",
-        "ssh_auth_server": "ssh://my_host.ssh:22",
         "history": {
             "created_at": "2018-08-29T12:23:13.981621+00:00",
             "started_at": "2018-08-29T12:23:15.988054+00:00",
@@ -670,8 +664,6 @@ async def test_job_run(
             },
         },
         "http_url": "http://my_host:8889",
-        "ssh_server": "ssh://my_host.ssh:22",
-        "ssh_auth_server": "ssh://my_host.ssh:22",
         "is_preemptible": False,
     }
 
@@ -768,8 +760,6 @@ async def test_job_run_with_name_and_description(
             },
         },
         "http_url": "http://my_host:8889",
-        "ssh_server": "ssh://my_host.ssh:22",
-        "ssh_auth_server": "ssh://my_host.ssh:22",
         "is_preemptible": False,
     }
 
@@ -872,8 +862,6 @@ async def test_job_run_with_tags(
             },
         },
         "http_url": "http://my_host:8889",
-        "ssh_server": "ssh://my_host.ssh:22",
-        "ssh_auth_server": "ssh://my_host.ssh:22",
         "is_preemptible": False,
     }
 
@@ -974,8 +962,6 @@ async def test_job_run_no_volumes(
             },
         },
         "http_url": "http://my_host:8889",
-        "ssh_server": "ssh://my_host.ssh:22",
-        "ssh_auth_server": "ssh://my_host.ssh:22",
         "is_preemptible": False,
     }
 
@@ -1054,8 +1040,6 @@ async def test_job_run_with_relative_volume_uris(
             },
         },
         "http_url": "http://my_host:8889",
-        "ssh_server": "ssh://my_host.ssh:22",
-        "ssh_auth_server": "ssh://my_host.ssh:22",
         "is_preemptible": False,
     }
 
@@ -1158,8 +1142,6 @@ async def test_job_run_with_secret_uris(
             },
         },
         "http_url": "http://my_host:8889",
-        "ssh_server": "ssh://my_host.ssh:22",
-        "ssh_auth_server": "ssh://my_host.ssh:22",
         "is_preemptible": False,
     }
 
@@ -1263,8 +1245,6 @@ async def test_job_run_with_disk_volume_uris(
             ],
         },
         "http_url": "http://my_host:8889",
-        "ssh_server": "ssh://my_host.ssh:22",
-        "ssh_auth_server": "ssh://my_host.ssh:22",
         "is_preemptible": False,
     }
 
@@ -1349,8 +1329,6 @@ async def test_job_run_preemptible(
         },
         "is_preemptible": True,
         "http_url": "http://my_host:8889",
-        "ssh_server": "ssh://my_host.ssh:22",
-        "ssh_auth_server": "ssh://my_host.ssh:22",
     }
 
     async def handler(request: web.Request) -> web.Response:
@@ -1451,8 +1429,6 @@ async def test_job_run_schedule_timeout(
             },
         },
         "http_url": "http://my_host:8889",
-        "ssh_server": "ssh://my_host.ssh:22",
-        "ssh_auth_server": "ssh://my_host.ssh:22",
         "is_preemptible": False,
         "schedule_timeout": 5,
     }
@@ -1525,8 +1501,6 @@ async def test_job_run_tpu(
             },
         },
         "http_url": "http://my_host:8889",
-        "ssh_server": "ssh://my_host.ssh:22",
-        "ssh_auth_server": "ssh://my_host.ssh:22",
         "is_preemptible": False,
     }
 
@@ -1630,7 +1604,6 @@ def create_job_response(
             "started_at": "2018-09-25T12:28:59.759433+00:00",
             "finished_at": "2018-09-25T12:28:59.759433+00:00",
         },
-        "ssh_auth_server": "ssh://my_host.ssh:22",
         "container": {
             "image": image,
             "command": "submit-command",
