@@ -52,6 +52,7 @@ def job_descr_no_name() -> JobDescription:
             status=JobStatus.PENDING,
             reason="ErrorReason",
             description="ErrorDesc",
+            restarts=0,
             created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
             started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
             finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -60,7 +61,6 @@ def job_descr_no_name() -> JobDescription:
             image=RemoteImage.new_external_image(name="ubuntu", tag="latest"),
             resources=Resources(16, 0.1, 0, None, False, None, None),
         ),
-        ssh_server=URL("ssh-auth"),
         is_preemptible=True,
     )
 
@@ -78,6 +78,7 @@ def job_descr() -> JobDescription:
             status=JobStatus.PENDING,
             reason="ErrorReason",
             description="ErrorDesc",
+            restarts=0,
             created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
             started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
             finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -86,7 +87,6 @@ def job_descr() -> JobDescription:
             image=RemoteImage.new_external_image(name="ubuntu", tag="latest"),
             resources=Resources(16, 0.1, 0, None, False, None, None),
         ),
-        ssh_server=URL("ssh-auth"),
         is_preemptible=True,
     )
 
@@ -113,6 +113,7 @@ class TestJobStartProgress:
                 status=status,
                 reason=reason,
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -122,7 +123,6 @@ class TestJobStartProgress:
                 image=RemoteImage.new_external_image(name="test-image"),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
             life_span=life_span,
         )
@@ -244,6 +244,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -255,7 +256,6 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
         )
 
@@ -299,6 +299,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -310,7 +311,6 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
         )
 
@@ -354,6 +354,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -365,7 +366,6 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
         )
 
@@ -411,6 +411,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -422,7 +423,6 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
             life_span=1.0 * ((60 * 60 * 24 * 1) + (60 * 60 * 2) + (60 * 3) + 4),
         )
@@ -466,6 +466,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -477,7 +478,6 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
             life_span=0.0,
         )
@@ -521,6 +521,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=4,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -532,7 +533,6 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
             restart_policy=JobRestartPolicy.ALWAYS,
         )
@@ -551,6 +551,7 @@ class TestJobOutputFormatter:
             "Command: test-command\n"
             f"{resource}\n"
             "Restart policy: always\n"
+            "Restarts: 4\n"
             "TTY: False\n"
             "Http URL: http://local.host.test/\n"
             "Http port: 80\n"
@@ -576,6 +577,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -587,7 +589,6 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
         )
 
@@ -625,6 +626,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="",
                 description="",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=None,
                 finished_at=None,
@@ -634,7 +636,6 @@ class TestJobOutputFormatter:
                 image=RemoteImage.new_external_image(name="test-image"),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=True,
             owner="owner",
             cluster_name="default",
@@ -668,6 +669,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="ContainerCreating",
                 description="",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=None,
                 finished_at=None,
@@ -678,7 +680,6 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 tty=True,
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=True,
             owner="owner",
             cluster_name="default",
@@ -712,6 +713,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="ContainerCreating",
                 description="",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=None,
                 finished_at=None,
@@ -721,7 +723,6 @@ class TestJobOutputFormatter:
                 command="test-command",
                 resources=Resources(16, 0.1, 0, None, False, None, None),
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=True,
             owner="owner",
             cluster_name="default",
@@ -757,6 +758,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.RUNNING,
                 reason="ContainerRunning",
                 description="",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:24.759433+00:00"),
                 finished_at=None,
@@ -767,7 +769,6 @@ class TestJobOutputFormatter:
                 image=RemoteImage.new_external_image(name="test-image"),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
             internal_hostname="host.local",
         )
@@ -805,6 +806,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.RUNNING,
                 reason="ContainerRunning",
                 description="",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:24.759433+00:00"),
                 finished_at=None,
@@ -815,7 +817,6 @@ class TestJobOutputFormatter:
                 image=RemoteImage.new_external_image(name="test-image"),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
             internal_hostname="host.local",
             internal_hostname_named="test-job--test-owner.local",
@@ -855,6 +856,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.RUNNING,
                 reason="ContainerRunning",
                 description="",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:24.759433+00:00"),
                 finished_at=None,
@@ -866,7 +868,6 @@ class TestJobOutputFormatter:
                 image=RemoteImage.new_external_image(name="test-image"),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
             internal_hostname="host.local",
         )
@@ -906,6 +907,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -924,7 +926,6 @@ class TestJobOutputFormatter:
                 http=HTTPPort(port=80, requires_auth=True),
                 env={"ENV_NAME_1": "__value1__", "ENV_NAME_2": "**value2**"},
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
         )
 
@@ -971,6 +972,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -1005,7 +1007,6 @@ class TestJobOutputFormatter:
                     ),
                 ],
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
         )
 
@@ -1053,6 +1054,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -1082,7 +1084,6 @@ class TestJobOutputFormatter:
                     ),
                 ],
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
         )
 
@@ -1128,6 +1129,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -1172,7 +1174,6 @@ class TestJobOutputFormatter:
                     "ENV_NAME_3": URL("secret://othercluster/otheruser/secret6"),
                 },
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
         )
 
@@ -1228,6 +1229,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -1262,7 +1264,6 @@ class TestJobOutputFormatter:
                     ),
                 ],
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
         )
 
@@ -1310,6 +1311,7 @@ class TestJobOutputFormatter:
                 status=JobStatus.PENDING,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -1328,7 +1330,6 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=False,
         )
 
@@ -1471,6 +1472,7 @@ class TestSimpleJobsFormatter:
                     status=JobStatus.PENDING,
                     reason="ErrorReason",
                     description="ErrorDesc",
+                    restarts=0,
                     created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                     started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                     finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -1479,7 +1481,6 @@ class TestSimpleJobsFormatter:
                     image=RemoteImage.new_external_image(name="ubuntu", tag="latest"),
                     resources=Resources(16, 0.1, 0, None, False, None, None),
                 ),
-                ssh_server=URL("ssh-auth"),
                 is_preemptible=True,
             ),
             JobDescription(
@@ -1493,6 +1494,7 @@ class TestSimpleJobsFormatter:
                     status=JobStatus.FAILED,
                     reason="ErrorReason",
                     description="ErrorDesc",
+                    restarts=0,
                     created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                     started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                     finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
@@ -1501,7 +1503,6 @@ class TestSimpleJobsFormatter:
                     image=RemoteImage.new_external_image(name="ubuntu", tag="latest"),
                     resources=Resources(16, 0.1, 0, None, False, None, None),
                 ),
-                ssh_server=URL("ssh-auth"),
                 is_preemptible=True,
             ),
         ]
@@ -1534,6 +1535,7 @@ class TestTabularJobRow:
                 status=status,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2017-01-02T12:28:21.298672+00:00"),
                 started_at=isoparse("2017-02-03T12:28:59.759433+00:00"),
                 finished_at=isoparse("2017-03-04T12:28:59.759433+00:00"),
@@ -1543,7 +1545,6 @@ class TestTabularJobRow:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 command="ls",
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=True,
         )
 
@@ -1653,6 +1654,7 @@ class TestTabularJobsFormatter:
                 status=JobStatus.FAILED,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=datetime.now(timezone.utc) - timedelta(seconds=1),
@@ -1662,7 +1664,6 @@ class TestTabularJobsFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 command="c",
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=True,
         )
         formatter = TabularJobsFormatter(
@@ -1704,6 +1705,7 @@ class TestTabularJobsFormatter:
                     status=JobStatus.FAILED,
                     reason="ErrorReason",
                     description="ErrorDesc",
+                    restarts=0,
                     created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                     started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                     finished_at=isoparse("2017-09-25T12:28:59.759433+00:00"),
@@ -1715,7 +1717,6 @@ class TestTabularJobsFormatter:
                     resources=Resources(16, 0.1, 0, None, False, None, None),
                     command="ls -la /some/path",
                 ),
-                ssh_server=URL("ssh-auth"),
                 is_preemptible=True,
             ),
             JobDescription(
@@ -1733,6 +1734,7 @@ class TestTabularJobsFormatter:
                     status=JobStatus.PENDING,
                     reason="",
                     description="",
+                    restarts=0,
                     created_at=isoparse("2017-09-25T12:28:21.298672+00:00"),
                     started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                     finished_at=isoparse("2017-09-25T12:28:59.759433+00:00"),
@@ -1748,7 +1750,6 @@ class TestTabularJobsFormatter:
                     resources=Resources(16, 0.1, 0, None, False, None, None),
                     command="ls -la /some/path",
                 ),
-                ssh_server=URL("ssh-auth"),
                 is_preemptible=True,
             ),
         ]
@@ -1776,6 +1777,7 @@ class TestTabularJobsFormatter:
                 status=JobStatus.FAILED,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                 finished_at=datetime.now(timezone.utc) - timedelta(seconds=1),
@@ -1785,7 +1787,6 @@ class TestTabularJobsFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 command="c",
             ),
-            ssh_server=URL("ssh-auth"),
             is_preemptible=True,
         )
 
@@ -1810,6 +1811,7 @@ class TestTabularJobsFormatter:
                     status=JobStatus.FAILED,
                     reason="ErrorReason",
                     description="ErrorDesc",
+                    restarts=0,
                     created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                     started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                     finished_at=datetime.now(timezone.utc) - timedelta(seconds=1),
@@ -1819,7 +1821,6 @@ class TestTabularJobsFormatter:
                     resources=Resources(16, 0.1, 0, None, False, None, None),
                     command="c",
                 ),
-                ssh_server=URL("ssh-auth"),
                 is_preemptible=True,
                 life_span=life_span,
             )
@@ -1844,6 +1845,7 @@ class TestTabularJobsFormatter:
                 status=JobStatus.PENDING,
                 reason="ContainerCreating",
                 description="",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=None,
                 finished_at=None,
@@ -1852,6 +1854,7 @@ class TestTabularJobsFormatter:
                 status=JobStatus.RUNNING,
                 reason="ContainerRunning",
                 description="",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:24.759433+00:00"),
                 finished_at=None,
@@ -1860,6 +1863,7 @@ class TestTabularJobsFormatter:
                 status=JobStatus.FAILED,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                 started_at=isoparse("2018-09-25T12:28:24.759433+00:00"),
                 finished_at=isoparse("2018-09-26T12:28:59.759433+00:00"),
@@ -1868,6 +1872,7 @@ class TestTabularJobsFormatter:
                 status=JobStatus.FAILED,
                 reason="ErrorReason",
                 description="ErrorDesc",
+                restarts=0,
                 created_at=datetime.now(timezone.utc) - timedelta(seconds=12345),
                 started_at=datetime.now(timezone.utc) - timedelta(seconds=1234),
                 finished_at=datetime.now(timezone.utc) - timedelta(seconds=12),
@@ -1887,7 +1892,6 @@ class TestTabularJobsFormatter:
                     image=RemoteImage.new_external_image(name="test-image"),
                     resources=Resources(16, 0.1, 0, None, False, None, None),
                 ),
-                ssh_server=URL("ssh-auth"),
                 is_preemptible=False,
                 internal_hostname="host.local",
             )
@@ -1920,6 +1924,7 @@ class TestTabularJobsFormatter:
                     status=JobStatus.FAILED,
                     reason="ErrorReason",
                     description="ErrorDesc",
+                    restarts=0,
                     created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
                     started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
                     finished_at=datetime.now(timezone.utc) - timedelta(seconds=1),
@@ -1930,7 +1935,6 @@ class TestTabularJobsFormatter:
                     resources=Resources(16, 0.1, 0, None, False, None, None),
                     working_dir=working_dir,
                 ),
-                ssh_server=URL("ssh-auth"),
                 is_preemptible=False,
                 internal_hostname="host.local",
             )
