@@ -1,3 +1,6 @@
+from datetime import timedelta
+
+import click
 import pytest
 
 from neuromation.cli.formatters.ftable import Align, ColumnWidth
@@ -7,6 +10,7 @@ from neuromation.cli.parse_utils import (
     get_default_columns,
     parse_columns,
     parse_memory,
+    parse_timedelta,
 )
 
 
@@ -17,29 +21,40 @@ def test_parse_memory() -> None:
 
     assert parse_memory("1K") == 1024
     assert parse_memory("2K") == 2048
+    assert parse_memory("1k") == 1024
+    assert parse_memory("2k") == 2048
     assert parse_memory("1kB") == 1000
     assert parse_memory("2kB") == 2000
+    assert parse_memory("1kb") == 1000
+    assert parse_memory("2kb") == 2000
 
     assert parse_memory("42M") == 42 * 1024 ** 2
     assert parse_memory("42MB") == 42 * 1000 ** 2
+    assert parse_memory("42Mb") == 42 * 1000 ** 2
 
     assert parse_memory("42G") == 42 * 1024 ** 3
     assert parse_memory("42GB") == 42 * 1000 ** 3
+    assert parse_memory("42Gb") == 42 * 1000 ** 3
 
     assert parse_memory("42T") == 42 * 1024 ** 4
     assert parse_memory("42TB") == 42 * 1000 ** 4
+    assert parse_memory("42Tb") == 42 * 1000 ** 4
 
     assert parse_memory("42P") == 42 * 1024 ** 5
     assert parse_memory("42PB") == 42 * 1000 ** 5
+    assert parse_memory("42Pb") == 42 * 1000 ** 5
 
     assert parse_memory("42E") == 42 * 1024 ** 6
     assert parse_memory("42EB") == 42 * 1000 ** 6
+    assert parse_memory("42Eb") == 42 * 1000 ** 6
 
     assert parse_memory("42Z") == 42 * 1024 ** 7
     assert parse_memory("42ZB") == 42 * 1000 ** 7
+    assert parse_memory("42Zb") == 42 * 1000 ** 7
 
     assert parse_memory("42Y") == 42 * 1024 ** 8
     assert parse_memory("42YB") == 42 * 1000 ** 8
+    assert parse_memory("42Yb") == 42 * 1000 ** 8
 
 
 def test_parse_columns_default() -> None:
@@ -131,3 +146,47 @@ def test_parse_columns_invalid_property() -> None:
 def test_parse_columns_ambigous() -> None:
     with pytest.raises(ValueError, match="Ambiguous column"):
         parse_columns("{c}")
+
+
+def test_parse_timedelta_valid_zero() -> None:
+    assert parse_timedelta("0") == timedelta(0)
+
+
+def test_parse_timedelta_valid_all_groups_no_spaces() -> None:
+    expected = timedelta(days=1, hours=2, minutes=3, seconds=4)
+    assert parse_timedelta("1d2h3m4s") == expected
+
+
+def test_parse_timedelta_valid_all_groups_spaces_around() -> None:
+    expected = timedelta(days=1, hours=2, minutes=3, seconds=4)
+    assert parse_timedelta("  1d2h3m4s ") == expected
+
+
+def test_parse_timedelta_valid_some_groups_1() -> None:
+    expected = timedelta(days=1, hours=2, seconds=4)
+    assert parse_timedelta("1d2h4s") == expected
+
+
+def test_parse_timedelta_valid_some_groups_2() -> None:
+    expected = timedelta(days=1, hours=1)
+    assert parse_timedelta("1d1h") == expected
+
+
+def test_parse_timedelta_valid_some_groups_3() -> None:
+    expected = timedelta(days=1)
+    assert parse_timedelta("1d") == expected
+
+
+def test_parse_timedelta_invalid_empty() -> None:
+    with pytest.raises(click.UsageError, match="Empty string not allowed"):
+        parse_timedelta("")
+
+
+def test_parse_timedelta_invalid() -> None:
+    with pytest.raises(click.UsageError, match="Should be like"):
+        parse_timedelta("invalid")
+
+
+def test_parse_timedelta_invalid_negative() -> None:
+    with pytest.raises(click.UsageError, match="Should be like"):
+        parse_timedelta("-1d")
