@@ -1,7 +1,7 @@
 import asyncio
 from dataclasses import replace
 from pathlib import Path
-from typing import Callable, Dict, Optional
+from typing import Any, Callable, Dict, Optional
 
 import aiohttp
 import aiohttp.pytest_plugin
@@ -16,6 +16,15 @@ from neuromation.api.tracing import _make_trace_config
 from neuromation.cli.asyncio_utils import setup_child_watcher
 
 
+def pytest_addoption(parser: Any, pluginmanager: Any) -> None:
+    parser.addoption(
+        "--rich-gen",
+        default=False,
+        action="store_true",
+        help="Regenerate rich_cmp references from captured texts",
+    )
+
+
 setup_child_watcher()
 
 
@@ -38,6 +47,7 @@ def auth_config() -> _AuthConfig:
     return _AuthConfig.create(
         auth_url=URL("https://dev-neuromation.auth0.com/authorize"),
         token_url=URL("https://dev-neuromation.auth0.com/oauth/token"),
+        logout_url=URL("https://dev-neuromation.auth0.com/v2/logout"),
         client_id="CLIENT-ID",
         audience="https://platform.dev.neuromation.io",
         headless_callback_url=URL("https://https://dev.neu.ro/oauth/show-code"),
