@@ -1,5 +1,6 @@
 import asyncio
 import asyncio.subprocess
+import errno
 import hashlib
 import logging
 import os
@@ -30,6 +31,7 @@ from uuid import uuid4 as uuid
 
 import aiodocker
 import aiohttp
+import click
 import pexpect
 import pytest
 import toml
@@ -39,6 +41,7 @@ from yarl import URL
 from neuromation.api import (
     Action,
     AuthorizationError,
+    Client,
     Config,
     Container,
     FileStatusType,
@@ -50,6 +53,7 @@ from neuromation.api import (
     get as api_get,
     login_with_token,
 )
+from neuromation.api.utils import asynccontextmanager
 from neuromation.cli.asyncio_utils import run
 from neuromation.cli.utils import resolve_job
 from tests.e2e.utils import FILE_SIZE_B, NGINX_IMAGE_NAME, JobWaitStateStopReached
@@ -481,15 +485,15 @@ class Helper:
             log.error(f"Last stdout: '{proc.stdout}'")
             log.error(f"Last stderr: '{proc.stderr}'")
             raise
-        out = proc.stdout
-        err = proc.stderr
+        out = click.unstyle(proc.stdout)
+        err = click.unstyle(proc.stderr)
         if any(run_cmd in arguments for run_cmd in ("submit", "run")):
             job_id = self.find_job_id(out)
             if job_id:
                 self._executed_jobs.append(job_id)
         out = out.strip()
         err = err.strip()
-        if verbosity > 0:
+        if verbosity > 3:
             print(f"neuro stdout: {out}")
             print(f"neuro stderr: {err}")
         return SysCap(out, err)
@@ -716,6 +720,11 @@ class Helper:
             )
             assert self.hash_hex(tmp_path) == checksum, "checksum test failed for {url}"
 
+    @asynccontextmanager
+    async def client(self) -> AsyncIterator[Client]:
+        async with api_get(timeout=CLIENT_TIMEOUT, path=self._nmrc_path) as client:
+            yield client
+
 
 # Cache at the session level to reduce amount of relogins.
 # Frequent relogins returns 500 Internal Server Error too often.
@@ -849,7 +858,14 @@ def _tmp_bucket_create(
 def tmp_bucket(_tmp_bucket_create: Tuple[str, Helper]) -> Iterator[str]:
     tmpbucketname, helper = _tmp_bucket_create
     yield tmpbucketname
-    helper.cleanup_bucket(tmpbucketname)
+    try:
+        helper.cleanup_bucket(tmpbucketname)
+    except aiohttp.ClientOSError as exc:
+        if exc.errno == errno.ETIMEDOUT:
+            # Try next time
+            pass
+        else:
+            raise
 
 
 @pytest.fixture
@@ -911,8 +927,7 @@ def disk_factory(helper: Helper) -> Callable[[str], ContextManager[str]]:
         # Create disk
         cap = helper.run_cli(["disk", "create", storage])
         assert cap.err == ""
-        disk_id, *_ = cap.out.splitlines()[1].split()
-
+        disk_id = cap.out.splitlines()[0].split()[1]
         yield disk_id
 
         # Remove disk
